@@ -444,9 +444,8 @@ variable.names.glmboost <- function(object, which = NULL, usedonly = FALSE, ...)
     ret[which]
 }
 
-
-selected <- function(object, ...)
-    UseMethod("selected", object)
+#selected <- function(object, ...)
+#    UseMethod("selected", object)
 
 selected.mboost <- function(object, ...)
     object$xselect()
